@@ -4,7 +4,7 @@ import (
 	"bytes"
 	"crypto/tls"
 	"fmt"
-	"io/ioutil"
+	"io"
 	"net/http"
 	"net/url"
 	"strings"
@@ -88,7 +88,7 @@ func (widget *Widget) jiraRequest(path string) ([]byte, error) {
 		return nil, fmt.Errorf(resp.Status)
 	}
 
-	body, err := ioutil.ReadAll(resp.Body)
+	body, err := io.ReadAll(resp.Body)
 	if err != nil {
 		return nil, err
 	}
@@ -97,7 +97,7 @@ func (widget *Widget) jiraRequest(path string) ([]byte, error) {
 }
 
 func getProjectQuery(projects []string) string {
-	singleEmptyProject := len(projects) == 1 && len(projects[0]) == 0
+	singleEmptyProject := len(projects) == 1 && projects[0] == ""
 	if len(projects) == 0 || singleEmptyProject {
 		return ""
 	} else if len(projects) == 1 {
